@@ -1,15 +1,15 @@
 package lib::allow;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-05-20'; # DATE
-our $DIST = 'lib-filter'; # DIST
-our $VERSION = '0.28'; # VERSION
-
 use strict;
 use warnings;
 
 require lib::filter;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-08-29'; # DATE
+our $DIST = 'lib-filter'; # DIST
+our $VERSION = '0.281'; # VERSION
+
 sub import {
     my $pkg = shift;
 
@@ -35,7 +35,7 @@ lib::allow - Only allow a list of modules to be locateable/loadable
 
 =head1 VERSION
 
-This document describes version 0.28 of lib::allow (from Perl distribution lib-filter), released on 2021-05-20.
+This document describes version 0.281 of lib::allow (from Perl distribution lib-filter), released on 2021-08-29.
 
 =head1 SYNOPSIS
 
@@ -61,14 +61,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/lib-filter
 
 Source repository is at L<https://github.com/perlancar/perl-lib-filter>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-lib-filter/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<lib::filter>
@@ -77,11 +69,36 @@ L<lib::filter>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2016, 2015 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2016, 2015 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=lib-filter>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
